==> opensearch-dashboards-2.16.0.tgz: opensearch-dashboards/src/plugins/data/common/types.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
var _types = require("./query/types");
Object.keys(_types).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (key in exports && exports[key] === _types[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _types[key];
    }
  });
});
var _types2 = require("./osd_field_types/types");
Object.keys(_types2).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (key in exports && exports[key] === _types2[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _types2[key];
    }
  });
});
var _types3 = require("./index_patterns/types");
Object.keys(_types3).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (key in exports && exports[key] === _types3[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _types3[key];
    }
  });
});
var _types4 = require("./data_frames/types");
Object.keys(_types4).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (key in exports && exports[key] === _types4[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _types4[key];
    }
  });
});
var _types5 = require("./data_sets/types");
Object.keys(_types5).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (key in exports && exports[key] === _types5[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _types5[key];
    }
  });
});

==> opensearch-dashboards-2.18.0.tgz: opensearch-dashboards/src/plugins/data/common/types.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
var _types = require("./query/types");
Object.keys(_types).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (key in exports && exports[key] === _types[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _types[key];
    }
  });
});
var _types2 = require("./osd_field_types/types");
Object.keys(_types2).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (key in exports && exports[key] === _types2[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _types2[key];
    }
  });
});
var _types3 = require("./index_patterns/types");
Object.keys(_types3).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (key in exports && exports[key] === _types3[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _types3[key];
    }
  });
});
var _types4 = require("./data_frames/types");
Object.keys(_types4).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (key in exports && exports[key] === _types4[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _types4[key];
    }
  });
});
var _types5 = require("./datasets/types");
Object.keys(_types5).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (key in exports && exports[key] === _types5[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _types5[key];
    }
  });
});
